@@ -208,8 +208,13 @@ func buildRPMMeta(info *nfpm.Info) (*rpmpack.RPMMetaData, error) {
 	if info.RPM.Compression == "" {
 		info.RPM.Compression = "gzip:-1"
 	}
-	if epoch, err = strconv.ParseUint(defaultTo(info.Epoch, "0"), 10, 32); err != nil {
-		return nil, err
+
+	if info.Epoch == "" {
+		epoch = uint64(rpmpack.NoEpoch)
+	} else {
+		if epoch, err = strconv.ParseUint(info.Epoch, 10, 32); err != nil {
+			return nil, err
+		}
 	}
 	if provides, err = toRelation(info.Provides); err != nil {
 		return nil, err
@@ -266,7 +271,7 @@ func formatVersion(info *nfpm.Info) string {
 	version := info.Version
 
 	if info.Prerelease != "" {
-		version += "~" + info.Prerelease
+		version += "~" + strings.ReplaceAll(info.Prerelease, "-", "_")
 	}
 
 	if info.VersionMetadata != "" {
@@ -342,6 +347,14 @@ func addScriptFiles(info *nfpm.Info, rpm *rpmpack.RPM) error {
 		rpm.AddPosttrans(string(data))
 	}
 
+	if info.RPM.Scripts.Verify != "" {
+		data, err := os.ReadFile(info.RPM.Scripts.Verify)
+		if err != nil {
+			return err
+		}
+		rpm.AddVerifyScript(string(data))
+	}
+
 	return nil
 }
 
@@ -360,6 +373,8 @@ func createFilesInsideRPM(info *nfpm.Info, rpm *rpmpack.RPM) (err error) {
 			file, err = asRPMFile(content, rpmpack.ConfigFile)
 		case files.TypeConfigNoReplace:
 			file, err = asRPMFile(content, rpmpack.ConfigFile|rpmpack.NoReplaceFile)
+		case files.TypeConfigMissingOK:
+			file, err = asRPMFile(content, rpmpack.ConfigFile|rpmpack.MissingOkFile)
 		case files.TypeRPMGhost:
 			if content.FileInfo.Mode == 0 {
 				content.FileInfo.Mode = os.FileMode(0o644)
